@@ -1,4 +1,4 @@
-plotcont = function(dat, score="score", main, xaxis.marks=seq(0,5,0.025)){
+plotcont = function(dat, score="S", main, xaxis.marks=seq(0,5,0.025)){
   x = unlist(dat[grep(score, colnames(dat))])
   plot(density(x[!is.na(x)]),  axes=FALSE, main=main)
   axis(1, at=xaxis.marks)
